Gencon SE Queensland CCQ Gencon Australia, Brisbane, Australia July 5th 2008 13 players Steven McRoy Deck Name: Arika Turbo Comments: Well the run is you get Arika out, wait a turn (hopefully no pentex, smash, or her getting torped), next you equip her with soul gem, Freak Drive to untap, then call Praxis S whatever to increase her capacity +1 and to make her prince of whatever, Awe it so you burn the blood off Arika down to 2, pass the vote with 22 votes for, now you are ready to bleed, force of will +2 bleed, daring the dawn to make it unblockable at inferior, conditioning for a bleed of 8, taking 3 agg damage burning Arika and a new ones comes into play. Play Praxis, Awe, Force of Will, Daring the Dawn, Conditioning bleed of 8, if you get stuck you can play distraction to not only get rid of the other soul gems and rubbish from your hand but to get back on track with the card combo. freak drive to then call PS repeat until you have wiped everyone out Crypt (15 cards, min=44, max=44, avg=11) ---------------------------------------- 15x Arika 11 DOM FOR OBF PRE aus cel inner circle Ventrue:2 -- could have more, 15 was enough Library (90 cards) Action (20) 10x Distraction 10x Force of Will Equipment (7) 7x Soul Gem of Etrius Political Action (10) 4x Praxis Seizure: Berlin 2x Praxis Seizure: Cairo 4x Praxis Seizure: Geneva Action Modifier (50) 10x Awe 10x Conditioning 10x Daring the Dawn 3x Elder Impersonation -- would exchange for Faceless Night x4 5x Forgotten Labyrinth -- would add one more 10x Freak Drive 2x Seduction -- would delete Combat (3) 3x Majesty